import { ISignal } from '@lumino/signaling';
import { Widget } from '@lumino/widgets';
import { IRenderMime } from '@jupyterlab/rendermime-interfaces';
import { OmniSciSQLEditor } from './grid';
import '../style/index.css';
/**
 * The MIME type for backend-rendered vega.
 */
export declare const VEGA_MIME_TYPE = "application/vnd.omnisci.vega+json";
/**
 * The MIME type for a SQL editor.
 */
export declare const SQL_EDITOR_MIME_TYPE = "application/vnd.omnisci.sqleditor+json";
/**
 * The MIME type for png data.
 */
export declare const IMAGE_MIME = "image/png";
/**
 * A class for rendering a OmniSci-generated image.
 */
export declare class RenderedOmniSciVega extends Widget implements IRenderMime.IRenderer {
    /**
     * Construct the rendered vega widget.
     */
    constructor();
    /**
     * Render OmniSci image into this widget's node.
     */
    renderModel(model: IRenderMime.IMimeModel): Promise<void>;
}
/**
 * A class for rendering a OmniSci-generated image.
 */
export declare class RenderedOmniSciSQLEditor extends Widget implements IRenderMime.IRenderer {
    /**
     * Construct the rendered sql editor widget.
     */
    constructor();
    /**
     * Get the underlying SQL editor.
     */
    readonly widget: OmniSciSQLEditor;
    /**
     * Render the SQL editor into this widget's node.
     */
    renderModel(model: IRenderMime.IMimeModel): Promise<void>;
    private _widget;
}
/**
 * A mime renderer factory for omnisci-vega data.
 */
export declare const vegaRendererFactory: IRenderMime.IRendererFactory;
/**
 * An interface for a SQL editor renderer factory that also exposes
 * a signal that fires when a renderer is created. We can subscribe
 * to this signal in the regular extensions in order to do some extra
 * work like setting up theming and completers. This is a slight abuse
 * of the mimerenderer system.
 */
export interface ISQLEditorRendererFactory extends IRenderMime.IRendererFactory {
    rendererCreated: ISignal<void, RenderedOmniSciSQLEditor>;
}
/**
 * A mime renderer factory for omnisci-sql-editor data.
 */
export declare const sqlEditorRendererFactory: ISQLEditorRendererFactory;
declare const extensions: IRenderMime.IExtension | IRenderMime.IExtension[];
export default extensions;
