import { Widget } from '@lumino/widgets';
import { ABCWidgetFactory, DocumentRegistry, DocumentWidget } from '@jupyterlab/docregistry';
import { IOmniSciConnectionData, IOmniSciConnectionManager } from './connection';
export declare class OmniSciVegaViewer extends DocumentWidget<Widget> {
    constructor(options: OmniSciVegaViewer.IOptions);
    /**
     * The current connection data for the viewer.
     */
    connectionData: IOmniSciConnectionData | undefined;
    /**
     * A promise that resolves when the viewer is ready.
     */
    readonly ready: Promise<void>;
    /**
     * Render OmniSci into this widget's node.
     */
    private _render;
    private _ready;
    private _widget;
    private _connectionData;
}
/**
 * A namespace for OmniSciVegaViewer statics.
 */
export declare namespace OmniSciVegaViewer {
    /**
     * Options to create a new document viewer.
     */
    interface IOptions {
        /**
         * A context for the document.
         */
        context: DocumentRegistry.IContext<DocumentRegistry.IModel>;
        /**
         * An options manager for the document.
         */
        manager: IOmniSciConnectionManager;
    }
}
/**
 * A widget factory for images.
 */
export declare class OmniSciVegaViewerFactory extends ABCWidgetFactory<OmniSciVegaViewer, DocumentRegistry.IModel> {
    constructor(options: OmniSciVegaViewerFactory.IOptions);
    /**
     * Create a new widget given a context.
     */
    protected createNewWidget(context: DocumentRegistry.IContext<DocumentRegistry.IModel>): OmniSciVegaViewer;
    private _manager;
}
export declare namespace OmniSciVegaViewerFactory {
    interface IOptions extends DocumentRegistry.IWidgetFactoryOptions {
        /**
         * A connection manager.
         */
        manager: IOmniSciConnectionManager;
    }
}
