"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const coreutils_1 = require("@lumino/coreutils");
const widgets_1 = require("@lumino/widgets");
const coreutils_2 = require("@jupyterlab/coreutils");
const apputils_1 = require("@jupyterlab/apputils");
const docregistry_1 = require("@jupyterlab/docregistry");
const widget_1 = require("./widget");
class OmniSciVegaViewer extends docregistry_1.DocumentWidget {
    constructor(options) {
        super({
            context: options.context,
            reveal: options.context.ready.then(() => this._render()),
            content: new widgets_1.Widget()
        });
        this._ready = new coreutils_1.PromiseDelegate();
        this._widget = null;
        this._connectionData = options.manager.defaultConnection;
        this.toolbar.addClass('omnisci-OmniSci-toolbar');
        this.addClass('omnisci-OmniSciVegaViewer');
        this.toolbar.addItem('Render', new apputils_1.ToolbarButton({
            iconClass: 'jp-RunIcon jp-Icon jp-Icon-16',
            onClick: () => {
                void this._render();
            },
            tooltip: 'Render'
        }));
        this.toolbar.addItem('Connect', new apputils_1.ToolbarButton({
            iconClass: 'omnisci-OmniSci-logo jp-Icon jp-Icon-16',
            onClick: () => {
                const name = coreutils_2.PathExt.basename(this.context.path);
                void options.manager
                    .chooseConnection(`Set Connection for ${name}`, this._connectionData)
                    .then(connectionData => {
                    this._connectionData = connectionData;
                });
            },
            tooltip: 'Enter OmniSci Connection Data'
        }));
    }
    /**
     * The current connection data for the viewer.
     */
    get connectionData() {
        return this._connectionData;
    }
    set connectionData(value) {
        this._connectionData = value;
        void this._render();
    }
    /**
     * A promise that resolves when the viewer is ready.
     */
    get ready() {
        return this._ready.promise;
    }
    /**
     * Render OmniSci into this widget's node.
     */
    _render() {
        if (this._widget) {
            this.content.node.removeChild(this._widget.node);
            this._widget.dispose();
            this._widget = null;
        }
        const text = this.context.model.toString();
        // If there is no data or no connection, do nothing
        if (!text || !this._connectionData) {
            return Promise.resolve(void 0);
        }
        const data = JSON.parse(text.replace(/\n/g, ''));
        this._widget = new widget_1.OmniSciVega({
            vega: data,
            connection: this._connectionData
        });
        this.content.node.appendChild(this._widget.node);
        const spinner = new apputils_1.Spinner();
        this.content.node.appendChild(spinner.node);
        return this._widget.renderedImage
            .then(() => {
            this.content.node.removeChild(spinner.node);
            spinner.dispose();
            return void 0;
        })
            .catch(() => {
            this.content.node.removeChild(spinner.node);
            spinner.dispose();
            return void 0;
        });
    }
}
exports.OmniSciVegaViewer = OmniSciVegaViewer;
/**
 * A widget factory for images.
 */
class OmniSciVegaViewerFactory extends docregistry_1.ABCWidgetFactory {
    constructor(options) {
        super(options);
        this._manager = options.manager;
    }
    /**
     * Create a new widget given a context.
     */
    createNewWidget(context) {
        return new OmniSciVegaViewer({ context, manager: this._manager });
    }
}
exports.OmniSciVegaViewerFactory = OmniSciVegaViewerFactory;
