"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const coreutils_1 = require("@lumino/coreutils");
const widgets_1 = require("@lumino/widgets");
const connection_1 = require("./connection");
/**
 * The MIME type for png data.
 */
const IMAGE_MIME = 'image/png';
/**
 * A class for rendering a OmniSci-generated image.
 */
class OmniSciVega extends widgets_1.Widget {
    /**
     * Construct a new OmniSci widget.
     */
    constructor(options) {
        super();
        this._rendered = new coreutils_1.PromiseDelegate();
        this.addClass('omnisci-OmniSciVega');
        this._img = document.createElement('img');
        this._error = document.createElement('pre');
        this._error.className = 'omnisci-ErrorMessage';
        this.node.appendChild(this._img);
        this.node.appendChild(this._error);
        this._connectionPromise = connection_1.makeConnection(options.connection, options.sessionId);
        this._vega = options.vega;
        // _vegaLite is just for debugging, in case we get an error, we can show it.
        this._vegaLite = options.vegaLite;
        void this._renderData();
    }
    get renderedImage() {
        return this._rendered.promise;
    }
    _renderData() {
        const vega = this._vega;
        return new Promise((resolve, reject) => {
            return this._connectionPromise
                .catch(error => {
                if (error) {
                    // If there was an error, clear any image data,
                    // and set the text content of the error node.
                    this._setImageData('');
                    this._error.textContent = error.error_msg || error;
                    this._rendered.reject(error);
                    return;
                }
            })
                .then(con => {
                con.renderVega(Private.id++, JSON.stringify(vega), {}, (error, result) => {
                    if (error) {
                        // If there was an error, clear any image data,
                        // and set the text content of the error node.
                        this._setImageData('');
                        this._error.textContent = error.message;
                        if (this._vegaLite) {
                            this._error.textContent += `\n\nVega Lite:\n${JSON.stringify(this._vegaLite, null, 2)}`;
                        }
                        this._error.textContent += `\n\nVega:\n${JSON.stringify(vega, null, 2)}`;
                        this._rendered.reject(error);
                    }
                    else {
                        // Set the image data.
                        this._setImageData(result.image);
                        // Clear any error message.
                        this._error.textContent = '';
                        this._rendered.resolve(result.image);
                    }
                });
            });
        });
    }
    /**
     * Set the image data to a base64 encoded string.
     */
    _setImageData(blob) {
        let blobUrl = `data:${IMAGE_MIME};base64,${blob}`;
        this._img.src = blobUrl;
    }
}
exports.OmniSciVega = OmniSciVega;
/**
 * A namespace for private data.
 */
var Private;
(function (Private) {
    Private.id = 0;
})(Private || (Private = {}));
